# mcapi
Materials Commons API

The "mature" version of the API in in the python directory. This 'master' of this directory
has also been released as a package in the Python Software
Foundation's python library: [materials-commons](https://pypi.python.org/pypi/materials-commons).
